{% extends 'dh5bp/base_script_in_head.html' %}
{% load staticfiles %}
{% load url from future %}
{% block head %}
    {% block dh5mbp_css %}
    {% comment %}
    This is remote and not included in the package, because I don't want to 
    be in the business of maintaining the images. The CSS will continue
    to be included with the package, but you'll have to have to jump
    through hoops to support images.
    {% endcomment %}
    <link rel="stylesheet" href="http://code.jquery.com/mobile/{{ dh5mbp_jqm_version|default:'1.4.2' }}/jquery.mobile-{{ dh5mbp_jqm_version|default:'1.4.2' }}.min.css" />
    {% endblock %}
 
    <!-- make iOS behave like native when installed on home screen -->
    <meta name="apple-mobile-web-app-capable" content="yes" />
    <meta name="apple-mobile-web-app-status-bar-style" content="black" />
    
    {% block dh5mbp_ios_icons %}
    <!-- all related iOS images -->
    <link rel="apple-touch-startup-image" href="{% static 'images/ios/startup-image.png' %}">
    <link rel="apple-touch-icon" href="{% static 'images/ios/touch-icon-ipad.png' %}" />
    <link rel="apple-touch-icon" sizes="72x72" href="{% static 'images/ios/touch-icon-ipad.png' %}" />
    <link rel="apple-touch-icon" sizes="114x114" href="{% static 'images/ios/touch-icon-iphone-retina.png' %}" />
    <link rel="apple-touch-icon" sizes="144x144" href="{% static 'images/ios/touch-icon-ipad-retina.png' %}" />
    {% endblock %}
{% endblock %}
{% block pre_main_script %}
	{% if not skip_add_to_home %}
    <script src="{% static 'js/dh5mbp/jquery-addToHome.min.js' %}"></script>
    {% endif %}
{% endblock %}
{% block post_main_script %}
    {% block dh5mbp_js %}
    <!-- use shared resources, when possible -->
    <script src="http://code.jquery.com/mobile/{{ dh5mbp_jqm_version|default:'1.4.2' }}/jquery.mobile-{{ dh5mbp_jqm_version|default:'1.4.2' }}.min.js"></script>
    {% with dh5mbp_jqm_version|default:'1.4.2' as temp %}
        <script>window.jQuery.mobile || document.write('<script src="{% static 'js/dh5mbp/jquery.mobile-'|add:temp|add:'.min.js' %}"><\/script>')</script>
    {% endwith %}
    {% endblock %}
{% endblock %}